package Polygons;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.image.BufferedImage;

import javax.swing.JFrame;
import javax.swing.JPanel;

class ImageViewer extends JPanel{
	
	static final long serialVersionUID=0;

    private BufferedImage canvas;
    private Color color;

    // required in order to work 
    public Dimension getPreferredSize() {
        return new Dimension(canvas.getWidth(), canvas.getHeight());
    }
    // required in order to work
    public void paintComponent(Graphics g) {
        super.paintComponent(g);
        Graphics2D g2 = (Graphics2D) g;
        g2.drawImage(canvas, null, null);
    }
    
    // open existing image
    private ImageViewer(BufferedImage img) {
	    JFrame frame = new JFrame("ImageView");
        canvas = img ;
		frame.add(this);
	    frame.pack();
	    frame.setVisible(true);
	    frame.setResizable(false);
	    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	    color = Color.black;
    }

    //-------------------------------------------------------------------------------
    // students: relevant for you is only the following part of the public interface 
    // ------------------------------------------------------------------------------
    
    // open empty image with dimensions width x height
    public ImageViewer(int width, int height)
    {
		this(new BufferedImage(width, height, BufferedImage.TYPE_INT_ARGB));
    }

    // empty image
    public void clear()
    {
        for (int y=0; y<canvas.getHeight(); ++y)
        	for (int x=0; x<canvas.getWidth(); ++x)
        		canvas.setRGB(x, y, 0);
    }
    
    // draw pixel at x,y
    // some safety: if out of bounds of the image, do nothing
    public void dot(int x, int y)
    {
    	
    	if (x<0 || y <0) return;
    	if (x>=canvas.getWidth() || y >= canvas.getHeight()) return;
    	
    	canvas.setRGB(x, y, color.getRGB());
    }
    
    // compact Bresenham: draw line from x0,y0 to x1,y1
	public void line(int x0, int y0, int x1, int y1)
	{
		int dx =  Math.abs(x1-x0), sx = x0<x1 ? 1 : -1;
		int dy = -Math.abs(y1-y0), sy = y0<y1 ? 1 : -1;
		int err = dx+dy, e2; /* error value e_xy */

		for(;;){  /* loop */
			dot(x0, y0);;
			if (x0==x1 && y0==y1) break;
			e2 = 2*err;
			if (e2 > dy) { err += dy; x0 += sx; } /* e_xy+e_x > 0 */
			if (e2 < dx) { err += dx; y0 += sy; } /* e_xy+e_y < 0 */
		}
	}
	
	
    // update content
    public void update()
    {
    	repaint();
    }

}

